@@ -14,7 +14,7 @@ pub enum Error {
 impl std::fmt::Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match *self {
-            Error::PivError(ref e) => write!(f, "{}", e.to_string()),
+            Error::PivError(ref e) => write!(f, "{}", e),
         }
     }
 }
